@@ -1,7 +1,7 @@
 """
 Type annotations for rds-data service type definitions.
 
-[Open documentation](./type_defs.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/type_defs.html)
 
 Usage::
 
@@ -197,7 +197,7 @@ SqlStatementResultTypeDef = TypedDict(
 StructValueTypeDef = TypedDict(
     "StructValueTypeDef",
     {
-        "attributes": List[Dict[str, Any]],
+        "attributes": List["ValueTypeDef"],
     },
     total=False,
 )
